"""
AA Fleet Pings
A couple of variables to use throughout the app
"""

# Django
from django.utils.translation import gettext_lazy as _

__version__ = "3.7.0"
__title__ = _("Fleet Pings")

__package_name__ = "aa-fleetpings"
__app_name__ = "fleetpings"
__app_name_verbose__ = "AA Fleet Pings"
__app_name_useragent__ = "AA-Fleet-Pings"

__github_url__ = f"https://github.com/ppfeufer/{__package_name__}"
